# -*- coding: utf-8 -*-
from yookassa.domain.common.payment_method_type import PaymentMethodType
from yookassa.domain.models.payout_data.payout_destination import PayoutDestination


class PayoutDestinationSbp(PayoutDestination):
    """Данные для выплаты через СБП на счет в банке или платежном сервисе."""  # noqa: E501

    __phone = None

    __bank_id = None

    __recipient_checked = None

    def __init__(self, *args, **kwargs):
        super(PayoutDestinationSbp, self).__init__(*args, **kwargs)
        if self.type is None or self.type is not PaymentMethodType.SBP:
            self.type = PaymentMethodType.SBP

    @property
    def phone(self):
        return self.__phone

    @phone.setter
    def phone(self, value):
        self.__phone = value

    @property
    def bank_id(self):
        return self.__bank_id

    @bank_id.setter
    def bank_id(self, value):
        self.__bank_id = value

    @property
    def recipient_checked(self):
        return self.__recipient_checked

    @recipient_checked.setter
    def recipient_checked(self, value):
        self.__recipient_checked = value



# -*- coding: utf-8 -*-
from yookassa.domain.common.payment_method_type import PaymentMethodType
from yookassa.domain.models.refund_data.refund_data import ResponseRefundData


class RefundDataSbp(ResponseRefundData):

    __sbp_operation_id = None

    def __init__(self, *args, **kwargs):
        super(RefundDataSbp, self).__init__(*args, **kwargs)
        if self.type is None or self.type is not PaymentMethodType.SBP:
            self.type = PaymentMethodType.SBP


    @property
    def sbp_operation_id(self):
        return self.__sbp_operation_id

    @sbp_operation_id.setter
    def sbp_operation_id(self, value):
        self.__sbp_operation_id = value



# -*- coding: utf-8 -*-
from yookassa.domain.request import SelfEmployedRequest


class SelfEmployedRequestBuilder(object):
    def __init__(self):
        self.__request = SelfEmployedRequest()

    def set_itn(self, value):
        self.__request.itn = value
        return self

    def set_phone(self, value):
        self.__request.phone = value
        return self

    def set_description(self, value):
        self.__request.description = value
        return self

    def set_confirmation(self, value):
        self.__request.confirmation = value
        return self

    def set_metadata(self, value):
        self.__request.metadata = value
        return self

    def build(self):
        return self.__request



# -*- coding: utf-8 -*-
from yookassa.domain.request import PersonalDataRequest


class PersonalDataRequestBuilder(object):
    def __init__(self):
        self.__request = PersonalDataRequest()

    def set_type(self, value):
        self.__request.type = value
        return self

    def set_last_name(self, value):
        self.__request.last_name = value
        return self

    def set_first_name(self, value):
        self.__request.first_name = value
        return self

    def set_middle_name(self, value):
        self.__request.middle_name = value
        return self

    def set_metadata(self, value):
        self.__request.metadata = value
        return self

    def build(self):
        return self.__request



# -*- coding: utf-8 -*-
from yookassa.domain.common.type_factory import TypeFactory
from yookassa.domain.models.self_employed_data.confirmation_class_map import SelfEmployedConfirmationClassMap


class SelfEmployedConfirmationFactory(TypeFactory):
    def __init__(self):
        super(SelfEmployedConfirmationFactory, self).__init__(SelfEmployedConfirmationClassMap())



# -*- coding: utf-8 -*-
from yookassa.domain.common.request_object import RequestObject
from yookassa.domain.models.self_employed_data.confirmation import SelfEmployedConfirmation
from yookassa.domain.models.self_employed_data.confirmation_factory import SelfEmployedConfirmationFactory

DESCRIPTION_MAX_LENGTH = 128


class SelfEmployedRequest(RequestObject):
    """Запрос на создание объекта самозанятого. """  # noqa: E501

    __itn = None

    __phone = None

    __confirmation = None

    __description = None

    __metadata = None

    @property
    def itn(self):
        return self.__itn

    @itn.setter
    def itn(self, value):
        self.__itn = value

    @property
    def phone(self):
        return self.__phone

    @phone.setter
    def phone(self, value):
        self.__phone = str(value)

    @property
    def confirmation(self):
        return self.__confirmation

    @confirmation.setter
    def confirmation(self, value):
        if isinstance(value, dict):
            self.__confirmation = SelfEmployedConfirmationFactory().create(value, self.context())
        elif isinstance(value, SelfEmployedConfirmation):
            self.__confirmation = value
        else:
            raise TypeError('Invalid confirmation data type in SelfEmployedRequest.confirmation')

    @property
    def description(self):
        return self.__description

    @description.setter
    def description(self, value):
        if value is not None and len(value) > DESCRIPTION_MAX_LENGTH:
            raise ValueError("Invalid value for `description`, length must be less than or equal to `{}`".format(DESCRIPTION_MAX_LENGTH))  # noqa: E501
        self.__description = value

    @property
    def metadata(self):
        return self.__metadata

    @metadata.setter
    def metadata(self, value):
        self.__metadata = value

    def validate(self):
        if self.itn is None and self.phone is None:
            self.__set_validation_error('Both itn and phone values are empty in self_employed_request')

    def __set_validation_error(self, message):
        raise ValueError(message)



# coding: utf-8
import re  # noqa: F401

from yookassa.domain.common import ResponseObject
from yookassa.domain.models.self_employed_data.confirmation import SelfEmployedConfirmation
from yookassa.domain.models.self_employed_data.confirmation_factory import SelfEmployedConfirmationFactory


class SelfEmployedResponse(ResponseObject):
    """Объект самозанятого. """  # noqa: E501

    __id = None

    __status = None

    __created_at = None

    __itn = None

    __phone = None

    __confirmation = None

    __description = None

    __metadata = None

    __test = None

    @property
    def id(self):
        return self.__id

    @id.setter
    def id(self, value):
        self.__id = value

    @property
    def status(self):
        return self.__status

    @status.setter
    def status(self, value):
        self.__status = str(value)

    @property
    def created_at(self):
        return self.__created_at

    @created_at.setter
    def created_at(self, value):
        self.__created_at = value

    @property
    def itn(self):
        return self.__itn

    @itn.setter
    def itn(self, value):
        self.__itn = value

    @property
    def phone(self):
        return self.__phone

    @phone.setter
    def phone(self, value):
        self.__phone = str(value)

    @property
    def confirmation(self):
        return self.__confirmation

    @confirmation.setter
    def confirmation(self, value):
        self.__confirmation = SelfEmployedConfirmationFactory().create(value, self.context())

    @property
    def description(self):
        return self.__description

    @description.setter
    def description(self, value):
        self.__description = value

    @property
    def metadata(self):
        return self.__metadata

    @metadata.setter
    def metadata(self, value):
        self.__metadata = value

    @property
    def test(self):
        return self.__test

    @test.setter
    def test(self, value):
        self.__test = value



# -*- coding: utf-8 -*-
import re

from yookassa.domain.common import BaseObject


class IndustryDetails(BaseObject):

    __federal_id = None

    __document_date = None

    __document_number = None

    __value = None

    @property
    def federal_id(self):
        return self.__federal_id

    @federal_id.setter
    def federal_id(self, value):
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `federal_id`, must not be `None`")  # noqa: E501
        if value is not None and not re.search(r'(^00[1-9]{1}$)|(^0[1-6]{1}[0-9]{1}$)|(^07[0-3]{1}$)', value):  # noqa: E501
            raise ValueError(r"Invalid value for `federal_id`, must be a follow pattern or equal to `/(^00[1-9]{1}$)|(^0[1-6]{1}[0-9]{1}$)|(^07[0-3]{1}$)/`")  # noqa: E501
        self.__federal_id = value

    @property
    def document_date(self):
        return self.__document_date

    @document_date.setter
    def document_date(self, value):
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `document_date`, must not be `None`")  # noqa: E501
        self.__document_date = value

    @property
    def document_number(self):
        return self.__document_number

    @document_number.setter
    def document_number(self, value):
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `document_number`, must not be `None`")  # noqa: E501
        if value is not None and len(value) > 32:
            raise ValueError("Invalid value for `document_number`, length must be less than or equal to `32`")  # noqa: E501
        self.__document_number = value

    @property
    def value(self):
        return self.__value

    @value.setter
    def value(self, value):
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `value`, must not be `None`")  # noqa: E501
        if value is not None and len(value) > 256:
            raise ValueError("Invalid value for `value`, length must be less than or equal to `256`")  # noqa: E501
        self.__value = value



# coding: utf-8
from yookassa.domain.common import BaseObject
from yookassa.domain.models import SbpParticipantBank


class SbpBankListResponse(BaseObject):
    """Список участников СБП, отсортированный по идентификатору участника в порядке убывания (desc)"""  # noqa: E501

    __type = None

    __items = None

    @property
    def type(self):
        return self.__type

    @type.setter
    def type(self, value):
        self.__type = value

    @property
    def items(self):
        return self.__items

    @items.setter
    def items(self, value):
        if isinstance(value, list):
            self.__items = [SbpParticipantBank(receipt) for receipt in value]
        else:
            self.__items = value



# coding: utf-8
import datetime
import re  # noqa: F401

from yookassa.domain.common import BaseObject


class SelfEmployedConfirmation(BaseObject):
    """
    Base class confirmation data objects
    """
    __type = None

    @property
    def type(self):
        return self.__type

    @type.setter
    def type(self, value):
        self.__type = str(value)


class SelfEmployedConfirmationType:
    """Код сценария подтверждения пользователем заявки ЮMoney на получение прав для регистрации чеков в сервисе Мой налог. """  # noqa: E501
    REDIRECT = 'redirect'



# coding: utf-8
import re  # noqa: F401

from yookassa.domain.common import BaseObject
from yookassa.domain.models import Amount


class IncomeReceipt(BaseObject):
    """Данные чека, зарегистрированного в ФНС. Присутствует, если вы делаете выплату [самозанятому](/developers/payouts/scenario-extensions/self-employed). """  # noqa: E501

    __service_name = None

    __npd_receipt_id = None

    __url = None

    __amount = None

    @property
    def service_name(self):
        return self.__service_name

    @service_name.setter
    def service_name(self, value):
        self.__service_name = value

    @property
    def npd_receipt_id(self):
        return self.__npd_receipt_id

    @npd_receipt_id.setter
    def npd_receipt_id(self, value):
        self.__npd_receipt_id = value

    @property
    def url(self):
        return self.__url

    @url.setter
    def url(self, value):
        self.__url = value

    @property
    def amount(self):
        return self.__amount

    @amount.setter
    def amount(self, value):
        if isinstance(value, dict):
            self.__amount = Amount(value)
        elif isinstance(value, Amount):
            self.__amount = value
        else:
            raise TypeError('Invalid amount data type in IncomeReceipt.amount')



# coding: utf-8
from yookassa.domain.common.response_object import ResponseObject
from yookassa.domain.models import CancellationDetails


class PersonalDataResponse(ResponseObject):
    """Информация о персональных данных"""  # noqa: E501

    __id = None

    __type = None

    __status = None

    __cancellation_details = None

    __created_at = None

    __expires_at = None

    __metadata = None

    @property
    def id(self):
        return self.__id

    @id.setter
    def id(self, value):
        self.__id = value

    @property
    def type(self):
        return self.__type

    @type.setter
    def type(self, value):
        self.__type = value

    @property
    def status(self):
        return self.__status

    @status.setter
    def status(self, value):
        self.__status = value

    @property
    def cancellation_details(self):
        return self.__cancellation_details

    @cancellation_details.setter
    def cancellation_details(self, value):
        self.__cancellation_details = CancellationDetails(value)

    @property
    def created_at(self):
        return self.__created_at

    @created_at.setter
    def created_at(self, value):
        self.__created_at = value

    @property
    def expires_at(self):
        return self.__expires_at

    @expires_at.setter
    def expires_at(self, value):
        self.__expires_at = value

    @property
    def metadata(self):
        return self.__metadata

    @metadata.setter
    def metadata(self, value):
        self.__metadata = value



# -*- coding: utf-8 -*-
import re  # noqa: F401

from yookassa.domain.common import BaseObject


class PayoutPersonalData(BaseObject):
    """Персональные данные получателя выплаты. Необходимо передавать, если вы делаете выплату с [проверкой получателя](/developers/payouts/scenario-extensions/recipient-check). Только для обычных выплат. """  # noqa: E501

    __id = None

    @property
    def id(self):
        return self.__id

    @id.setter
    def id(self, value):
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501
        if value is not None and len(value) > 50:
            raise ValueError("Invalid value for `id`, length must be less than or equal to `50`")  # noqa: E501
        if value is not None and len(value) < 36:
            raise ValueError("Invalid value for `id`, length must be greater than or equal to `36`")  # noqa: E501
        self.__id = value


class PersonalDataType(object):
    """Тип персональных данных — цель, для которой вы будете использовать данные. Возможное значение: `sbp_payout_recipient` — выплаты с %[проверкой получателя](/developers/payouts/scenario-extensions/recipient-check). """  # noqa: E501

    SBP_PAYOUT_RECIPIENT = "sbp_payout_recipient"


class PersonalDataStatus(object):
    """Статус персональных данных. Возможные значения:  * ~`waiting_for_operation` — данные сохранены, но не использованы при проведении выплаты; * ~`active` — данные сохранены и использованы при проведении выплаты; данные можно использовать повторно до срока, указанного в параметре `expires_at`; * ~`canceled` — хранение данных отменено, данные удалены, инициатор и причина отмены указаны в объекте cancellation_details (финальный и неизменяемый статус)."""  # noqa: E501

    WAITING_FOR_OPERATION = "waiting_for_operation"
    ACTIVE = "active"
    CANCELED = "canceled"



# coding: utf-8
import re  # noqa: F401

from yookassa.domain.common.request_object import RequestObject


class PersonalDataRequest(RequestObject):

    __type = None

    __last_name = None

    __first_name = None

    __middle_name = None

    __metadata = None

    @property
    def type(self):
        return self.__type

    @type.setter
    def type(self, value):
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        self.__type = str(value)

    @property
    def last_name(self):
        return self.__last_name

    @last_name.setter
    def last_name(self, value):
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `last_name`, must not be `None`")  # noqa: E501
        if value is not None and len(value) > 200:
            raise ValueError("Invalid value for `last_name`, length must be less than or equal to `200`")  # noqa: E501
        if value is not None and len(value) < 1:
            raise ValueError("Invalid value for `last_name`, length must be greater than or equal to `1`")  # noqa: E501
        if value is not None and not re.search(r'^[—–‐\-a-zA-Zа-яёА-ЯЁ ]*$', value):  # noqa: E501
            raise ValueError(r"Invalid value for `last_name`, must be a follow pattern or equal to `/^[—–‐\-a-zA-Zа-яёА-ЯЁ ]*$/`")  # noqa: E501
        self.__last_name = value

    @property
    def first_name(self):
        return self.__first_name

    @first_name.setter
    def first_name(self, value):
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `first_name`, must not be `None`")  # noqa: E501
        if value is not None and len(value) > 100:
            raise ValueError("Invalid value for `first_name`, length must be less than or equal to `100`")  # noqa: E501
        if value is not None and len(value) < 1:
            raise ValueError("Invalid value for `first_name`, length must be greater than or equal to `1`")  # noqa: E501
        if value is not None and not re.search(r'^[—–‐\-a-zA-Zа-яёА-ЯЁ ]*$', value):  # noqa: E501
            raise ValueError(r"Invalid value for `first_name`, must be a follow pattern or equal to `/^[—–‐\-a-zA-Zа-яёА-ЯЁ ]*$/`")  # noqa: E501
        self.__first_name = value

    @property
    def middle_name(self):
        return self.__middle_name

    @middle_name.setter
    def middle_name(self, value):
        if value is not None and len(value) > 200:
            raise ValueError("Invalid value for `middle_name`, length must be less than or equal to `200`")  # noqa: E501
        if value is not None and len(value) < 1:
            raise ValueError("Invalid value for `middle_name`, length must be greater than or equal to `1`")  # noqa: E501
        if value is not None and not re.search(r'^[—–‐\-a-zA-Zа-яёА-ЯЁ ]*$', value):  # noqa: E501
            raise ValueError(r"Invalid value for `middle_name`, must be a follow pattern or equal to `/^[—–‐\-a-zA-Zа-яёА-ЯЁ ]*$/`")  # noqa: E501
        self.__middle_name = value

    @property
    def metadata(self):
        return self.__metadata

    @metadata.setter
    def metadata(self, value):
        self.__metadata = value

    def validate(self):
        if self.type is None or self.last_name is None or self.first_name is None:
            self.__set_validation_error('Type, last_name and first_name values cannot be empty in PersonalDataRequest')  # noqa: E501

    def __set_validation_error(self, message):
        raise ValueError(message)



# coding: utf-8
from yookassa.domain.common import BaseObject


class SbpParticipantBank(BaseObject):
    """Участник СБП (Системы быстрых платежей ЦБ РФ)"""  # noqa: E501

    __bank_id = None

    __name = None

    __bic = None

    @property
    def bank_id(self):
        return self.__bank_id

    @bank_id.setter
    def bank_id(self, value):
        self.__bank_id = str(value)

    @property
    def name(self):
        return self.__name

    @name.setter
    def name(self, value):
        self.__name = str(value)

    @property
    def bic(self):
        return self.__bic

    @bic.setter
    def bic(self, value):
        self.__bic = str(value)



# coding: utf-8
import datetime
import re  # noqa: F401

from yookassa.domain.common import BaseObject


class MerchantCustomerBankAccount(BaseObject):

    __account_number = None

    __bic = None

    @property
    def account_number(self):
        return self.__account_number

    @account_number.setter
    def account_number(self, value):
        if value is not None and not re.search(r'^[0-9]{20}$', value):  # noqa: E501
            raise ValueError("Invalid value for `account_number`, must be a follow pattern or equal to `/[0-9]{20}/`")  # noqa: E501
        self.__account_number = value

    @property
    def bic(self):
        return self.__bic

    @bic.setter
    def bic(self, value):
        if value is not None and not re.search(r'^\d{9}$', value):  # noqa: E501
            raise ValueError(r"Invalid value for `bic`, must be a follow pattern or equal to `/\d{9}/`")  # noqa: E501
        self.__bic = value



# -*- coding: utf-8 -*-
from yookassa.domain.common import BaseObject


class OperationalDetails(BaseObject):

    __operation_id = None

    __value = None

    __created_at = None

    @property
    def operation_id(self):
        return self.__operation_id

    @operation_id.setter
    def operation_id(self, value):
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `operation_id`, must not be `None`")  # noqa: E501
        if not isinstance(value, int):  # noqa: E501
            raise TypeError("Invalid value type for `operation_id`, must be `int`")  # noqa: E501
        if value is not None and value > 255:  # noqa: E501
            raise ValueError("Invalid value for `operation_id`, must be a value less than or equal to `255`")  # noqa: E501
        if value is not None and value < 0:  # noqa: E501
            raise ValueError("Invalid value for `operation_id`, must be a value greater than or equal to `0`")  # noqa: E501
        self.__operation_id = value

    @property
    def value(self):
        return self.__value

    @value.setter
    def value(self, value):
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `value`, must not be `None`")  # noqa: E501
        if value is not None and len(value) > 64:
            raise ValueError("Invalid value for `value`, length must be less than or equal to `64`")  # noqa: E501
        self.__value = value

    @property
    def created_at(self):
        return self.__created_at

    @created_at.setter
    def created_at(self, value):
        if value is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501
        self.__created_at = value



# -*- coding: utf-8 -*-
import re
from decimal import Decimal

from yookassa.domain.common import BaseObject
from yookassa.domain.models.amount import Amount
from yookassa.domain.models.receipt_data.industry_details import IndustryDetails
from yookassa.domain.models.receipt_data.mark_code_info import MarkCodeInfo
from yookassa.domain.models.receipt_data.mark_quantity import MarkQuantity


class ReceiptItem(BaseObject):
    """
    Class representing receipt item data wrapper object

    Used in Receipt
    """
    __description = None

    __amount = None

    __vat_code = None

    __quantity = None

    __measure = None

    __mark_quantity = None

    __payment_subject = None

    __payment_mode = None

    __country_of_origin_code = None

    __customs_declaration_number = None

    __excise = None

    __product_code = None

    __mark_code_info = None

    __mark_mode = None

    __payment_subject_industry_details = None

    @property
    def description(self):
        return self.__description

    @description.setter
    def description(self, value):
        self.__description = str(value)

    @property
    def amount(self):
        return self.__amount

    @amount.setter
    def amount(self, value):
        if isinstance(value, dict):
            self.__amount = Amount(value)
        elif isinstance(value, Amount):
            self.__amount = value
        else:
            raise TypeError('Invalid amount value type')

    @property
    def vat_code(self):
        return self.__vat_code

    @vat_code.setter
    def vat_code(self, value):
        self.__vat_code = int(value)

    @property
    def quantity(self):
        """
        :return Decimal:
        """
        return self.__quantity

    @quantity.setter
    def quantity(self, value):
        self.__quantity = Decimal(str(float(value)))

    @property
    def measure(self):
        return self.__measure

    @measure.setter
    def measure(self, value):
        self.__measure = value

    @property
    def mark_quantity(self):
        return self.__mark_quantity

    @mark_quantity.setter
    def mark_quantity(self, value):
        if isinstance(value, dict):
            self.__mark_quantity = MarkQuantity(value)
        elif isinstance(value, MarkQuantity):
            self.__mark_quantity = value
        else:
            raise TypeError('Invalid mark_quantity data type in ReceiptItem.mark_quantity')

    @property
    def payment_subject(self):
        return self.__payment_subject

    @payment_subject.setter
    def payment_subject(self, value):
        self.__payment_subject = str(value)

    @property
    def payment_mode(self):
        return self.__payment_mode

    @payment_mode.setter
    def payment_mode(self, value):
        self.__payment_mode = str(value)

    @property
    def country_of_origin_code(self):
        return self.__country_of_origin_code

    @country_of_origin_code.setter
    def country_of_origin_code(self, value):
        self.__country_of_origin_code = str(value)

    @property
    def customs_declaration_number(self):
        return self.__customs_declaration_number

    @customs_declaration_number.setter
    def customs_declaration_number(self, value):
        self.__customs_declaration_number = str(value)

    @property
    def excise(self):
        """
        :return Decimal:
        """
        return self.__excise

    @excise.setter
    def excise(self, value):
        self.__excise = Decimal(str(value))

    @property
    def product_code(self):
        return self.__product_code

    @product_code.setter
    def product_code(self, value):
        self.__product_code = str(value)

    @property
    def mark_code_info(self):
        return self.__mark_code_info

    @mark_code_info.setter
    def mark_code_info(self, value):
        if isinstance(value, dict):
            self.__mark_code_info = MarkCodeInfo(value)
        elif isinstance(value, MarkCodeInfo):
            self.__mark_code_info = value
        else:
            raise TypeError('Invalid mark_code_info data type in ReceiptItem.mark_code_info')

    @property
    def mark_mode(self):
        return self.__mark_mode

    @mark_mode.setter
    def mark_mode(self, value):
        if value is not None and not re.search(r'^[0]{1}$', value):  # noqa: E501
            raise ValueError(r"Invalid value for `mark_mode`, must be a follow pattern or equal to `/^[0]{1}$/`")  # noqa: E501
        self.__mark_mode = value

    @property
    def payment_subject_industry_details(self):
        return self.__payment_subject_industry_details

    @payment_subject_industry_details.setter
    def payment_subject_industry_details(self, value):
        if isinstance(value, list):
            items = []
            for item in value:
                if isinstance(item, dict):
                    items.append(IndustryDetails(item))
                elif isinstance(item, IndustryDetails):
                    items.append(item)
                else:
                    raise TypeError(
                        'Invalid payment_subject_industry_details data type in ReceiptItem.payment_subject_industry_details')
            self.__payment_subject_industry_details = items
        else:
            raise TypeError('Invalid payment_subject_industry_details value type in ReceiptItem')


class PaymentMode(object):
    """
    Class representing payment_mode values enum
    """
    FULL_PREPAYMENT = 'full_prepayment'
    PARTIAL_PREPAYMENT = 'partial_prepayment'
    ADVANCE = 'advance'
    FULL_PAYMENT = 'full_payment'
    PARTIAL_PAYMENT = 'partial_payment'
    CREDIT = 'credit'
    CREDIT_PAYMENT = 'credit_payment'


class PaymentSubject(object):
    """
    Class representing payment_subject values enum
    """
    COMMODITY = 'commodity'
    EXCISE = 'excise'
    JOB = 'job'
    SERVICE = 'service'
    GAMBLING_BET = 'gambling_bet'
    GAMBLING_PRIZE = 'gambling_prize'
    LOTTERY = 'lottery'
    LOTTERY_PRIZE = 'lottery_prize'
    INTELLECTUAL_ACTIVITY = 'intellectual_activity'
    PAYMENT = 'payment'
    AGENT_COMMISSION = 'agent_commission'
    COMPOSITE = 'composite'
    ANOTHER = 'another'


class ReceiptItemMeasure(object):
    PIECE = 'piece'
    GRAM = 'gram'
    KILOGRAM = 'kilogram'
    TON = 'ton'
    CENTIMETER = 'centimeter'
    DECIMETER = 'decimeter'
    METER = 'meter'
    SQUARE_CENTIMETER = 'square_centimeter'
    SQUARE_DECIMETER = 'square_decimeter'
    SQUARE_METER = 'square_meter'
    MILLILITER = 'milliliter'
    LITER = 'liter'
    CUBIC_METER = 'cubic_meter'
    KILOWATT_HOUR = 'kilowatt_hour'
    GIGACALORIE = 'gigacalorie'
    DAY = 'day'
    HOUR = 'hour'
    MINUTE = 'minute'
    SECOND = 'second'
    KILOBYTE = 'kilobyte'
    MEGABYTE = 'megabyte'
    GIGABYTE = 'gigabyte'
    TERABYTE = 'terabyte'
    ANOTHER = 'another'
